@@ -31,9 +31,9 @@ func TestExecutableIsAbsoluteOnAllPlatforms(t *testing.T) {
 }
 
 func TestInit(t *testing.T) {
-	scheduler := NewScheduler(NewHandler(SchedulerDefaultOS{}), "profile")
-	err := scheduler.Init()
-	defer scheduler.Close()
+	handler := (NewHandler(SchedulerDefaultOS{}))
+	err := handler.Init()
+	defer handler.Close()
 	require.NoError(t, err)
 }
 
@@ -41,9 +41,9 @@ func TestCrondInit(t *testing.T) {
 	if platform.IsWindows() {
 		t.Skip("crond scheduler is not supported on this platform")
 	}
-	scheduler := NewScheduler(NewHandler(SchedulerCrond{}), "profile")
-	err := scheduler.Init()
-	defer scheduler.Close()
+	handler := (NewHandler(SchedulerCrond{}))
+	err := handler.Init()
+	defer handler.Close()
 	require.NoError(t, err)
 }
 
@@ -51,26 +51,26 @@ func TestSystemdInit(t *testing.T) {
 	if platform.IsWindows() || platform.IsDarwin() {
 		t.Skip("systemd scheduler is not supported on this platform")
 	}
-	scheduler := NewScheduler(NewHandler(SchedulerSystemd{}), "profile")
-	err := scheduler.Init()
-	defer scheduler.Close()
+	handler := (NewHandler(SchedulerSystemd{}))
+	err := handler.Init()
+	defer handler.Close()
 	require.NoError(t, err)
 }
 func TestLaunchdInit(t *testing.T) {
 	if !platform.IsDarwin() {
 		t.Skip("launchd scheduler is not supported on this platform")
 	}
-	scheduler := NewScheduler(NewHandler(SchedulerLaunchd{}), "profile")
-	err := scheduler.Init()
-	defer scheduler.Close()
+	handler := (NewHandler(SchedulerLaunchd{}))
+	err := handler.Init()
+	defer handler.Close()
 	require.NoError(t, err)
 }
 func TestWindowsInit(t *testing.T) {
 	if !platform.IsWindows() {
 		t.Skip("windows scheduler is not supported on this platform")
 	}
-	scheduler := NewScheduler(NewHandler(SchedulerWindows{}), "profile")
-	err := scheduler.Init()
-	defer scheduler.Close()
+	handler := (NewHandler(SchedulerWindows{}))
+	err := handler.Init()
+	defer handler.Close()
 	require.NoError(t, err)
 }
