@@ -3,12 +3,12 @@
 package main
 
 import (
-	"errors"
 	"testing"
 
 	"github.com/creativeprojects/clog"
 	"github.com/creativeprojects/go-selfupdate"
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 )
 
 func TestUpdate(t *testing.T) {
@@ -20,7 +20,6 @@ func TestUpdate(t *testing.T) {
 	defer clog.CloseTestLog()
 
 	err := confirmAndSelfUpdate(true, true, "0.0.1", false)
-	assert.Error(t, err)
-	assert.Truef(t, errors.Is(err, selfupdate.ErrExecutableNotFoundInArchive), "error returned isn't wrapping %q but is instead: %q", selfupdate.ErrExecutableNotFoundInArchive, err)
+	require.ErrorIsf(t, err, selfupdate.ErrExecutableNotFoundInArchive, "error returned isn't wrapping %q but is instead: %q", selfupdate.ErrExecutableNotFoundInArchive, err)
 	assert.Contains(t, err.Error(), "resticprofile.test")
 }
